# Aliste Smart Home SDK for Python

### Installation

```
pip install aliste
```

### Get started

```Python
from aliste import AlisteHub, AlisteBroker

# Instantiate a MirAIeHub object
broker = AlisteBroker()

# Instantiate a MirAIeHub object
hub = AlisteHub()

# Intialize the hub (+91xxxxxxxxxx, password, broker)
hub.init(mobile, password, broker)
```
